﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            NameScope.SetNameScope(this, new NameScope());

            #region 사각형 지오메트리를 생성한다.

            RectangleGeometry rectangleGeometry = new RectangleGeometry();

            rectangleGeometry.Rect = new Rect(0, 200, 100, 100);

            RegisterName("rectangleGeometry", rectangleGeometry);

            #endregion
            #region 패스를 생성한다.

            Path path = new Path();

            path.StrokeThickness = 1;
            path.Stroke          = Brushes.Black;
            path.Fill            = Brushes.LemonChiffon;
            path.Data            = rectangleGeometry;

            #endregion
            #region 스택 패널을 생성한다.

            StackPanel stackPanel = new StackPanel();

            stackPanel.HorizontalAlignment = HorizontalAlignment.Center;
            stackPanel.Background          = Brushes.LightGray;
            stackPanel.Orientation         = Orientation.Vertical;

            stackPanel.Children.Add(path);

            #endregion
            #region 사각형 애니메이션을 생성한다.

            RectAnimationUsingKeyFrames rectangleAnimation = new RectAnimationUsingKeyFrames();

            rectangleAnimation.Duration       = TimeSpan.FromSeconds(6);
            rectangleAnimation.RepeatBehavior = RepeatBehavior.Forever;

            rectangleAnimation.KeyFrames.Add
            (
                new LinearRectKeyFrame
                (
                    new Rect(600, 50, 200, 50),
                    KeyTime.FromTimeSpan(TimeSpan.FromSeconds(2))
                )
            );

            rectangleAnimation.KeyFrames.Add
            (
                new DiscreteRectKeyFrame
                (
                    new Rect(600, 50, 200, 10),
                    KeyTime.FromTimeSpan(TimeSpan.FromSeconds(2.5))
                )
            );

            rectangleAnimation.KeyFrames.Add
            (
                new SplineRectKeyFrame
                (
                    new Rect(0, 200, 100, 100),
                    KeyTime.FromTimeSpan(TimeSpan.FromSeconds(4.5)),
                    new KeySpline(0.6, 0.0, 0.9, 0.0)
                )
            );

            Storyboard.SetTargetName(rectangleAnimation, "rectangleGeometry");
            Storyboard.SetTargetProperty(rectangleAnimation, new PropertyPath(RectangleGeometry.RectProperty));

            #endregion
            #region 스토리보드를 생성한다.

            Storyboard storyboard = new Storyboard();

            storyboard.Children.Add(rectangleAnimation);

            #endregion

            path.Loaded += delegate(object sender, RoutedEventArgs e)
            {
                storyboard.Begin(this);
            };

            Content = stackPanel;
        }

        #endregion
    }
}